==> release.12.0.73.1.tgz: cgi-cpn/prontus_s3_erase.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# PROPOSITO .
# -----------
# Listar archivos pertenecientes a un Prontus y articulo en un almacenamiento S3
#
use strict;
use warnings;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibs = $Bin;
    unshift(@INC,$pathLibs);

    $pathLibs = "$pathLibs/mam";
    unshift(@INC, $pathLibs);
}

END {
    &tareas_salida();
}

use Net::Amazon::S3;
use JSON;
require HTTP::Headers;

# Captura STDERR
use lib_stdlog;
&lib_stdlog::set_stdlog();
use prontus_varglb; &prontus_varglb::init();
use mime_types;
use glib_fildir_03;
use lib_mam;
use lib_prontus;
use lib_s3;
use lib_artic;
use lib_waitlock;

use Data::Dumper;

our $LOCK = '';
our $LOCKFH;
our $BD;

main: {
    lib_prontus::setUtf8();

    if (scalar @ARGV < 2) {
        print "Parámetros insuficientes. Modo de uso:\n";
        print "perl $0 <prontus_id> <ts_articulo>\n";
        exit;
    }

    $prontus_varglb::PRONTUS_ID = $ARGV[0];

    my $ts = '';
    if (defined($ARGV[1]) && $ARGV[1] =~ /^\d{14}$/) {
        $ts = $ARGV[1];
    } elsif ($ARGV[1]) {
        print "Parámetro [$ARGV[1]] no es válido\n";
        exit;
    }

    my $msg_load = &lib_prontus::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "Ha ocurrido un error: $msg_load\n";
        exit;
    }

    if (!lib_s3::check_config_s3()) {
        print STDERR "S3 no habilitado y/o configurado\n";
        exit;
    }

    my ($result, $msg_err) = &lib_prontus::get_url("https://".$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'S3_ENDPOINT'}, 10);
    if ($msg_err) {
        print STDERR "Error al conectar con endpoint S3 [$msg_err]\n";
        exit;
    }

    # se asegura el xml mientras se edita y guarda
    $LOCK = "$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_LOCKS'}/$ts.mutex";
    $LOCKFH = &lib_waitlock::lock_file($LOCK);

    # actualizar xml de artículo
    my $artic_obj;
    # se instancia el articulo con los campos nuevos
    unless($artic_obj = Artic->new(
                'prontus_id'         => $prontus_varglb::PRONTUS_ID,
                'public_server_name' => $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PUBLIC_SERVER_NAME'},
                'cpan_server_name'   => $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'CPAN_SERVER_NAME'},
                'document_root'      => $prontus_varglb::DIR_SERVER,
                'ts'                 => $ts,
                'no_check_dirs'      => 1)) {
        print STDERR "[Error] inicializando objeto articulo: $Artic::ERR\n";
        exit;
    };

    $artic_obj->{xml_data} = &glib_fildir_03::read_file($artic_obj->{fullpath_xml});

    my $fechac = substr($ts, 0, 8);
    # buscamos campos en articulo para borrar archivos que ya no pertenecen al artículo
    my %campos_xml = %{lib_artic::carga_art_xml($artic_obj->{fullpath_xml})};

    my $dst_base = substr($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'}, 1);
    my $dst_base_mm    = "$dst_base$prontus_varglb::DIR_EXMEDIA/$fechac$prontus_varglb::DIR_MMEDIA/";
    my $dst_base_docs  = "$dst_base$prontus_varglb::DIR_ASOCFILE/$fechac/$ts/";

    my %asocfiles;
    my @multimedia;
    foreach my $nom (keys %campos_xml) {
        if ($nom =~ /^multimedia_\w+$/) {
            push(@multimedia, $nom);
        }
        elsif ($nom =~ /^asocfile_\w+$/) {
            $asocfiles{"$dst_base_docs$campos_xml{$nom}"} = 1;
        }
    }

    lib_s3::connect_s3();
    my $bucket = lib_s3::connect_bucket();

    my $borrado = 0;
    my @s3_files = lib_s3::list_files_pattern($bucket, $dst_base_mm);
    foreach my $remote (@s3_files) {
        next if ($remote->key !~ /$ts/);
        my $found = 0;
        foreach my $marca (@multimedia) {
            if ($remote->key =~ /$marca$ts/) {
                $found = 1;
                last;
            }
        }
        if (!$found) {
            lib_s3::delete_file_key($bucket, $remote->key);
            $borrado = 1;
        }
    }

    @s3_files = lib_s3::list_files_pattern($bucket, $dst_base_docs);
    foreach my $remote (@s3_files) {
        if (!defined($asocfiles{$remote->key})) {
            lib_s3::delete_file_key($bucket, $remote->key);
            $borrado = 1;
        }
    }

    # no se borro nada del s3, no hay que actualizar el tamaño del artículo
    if (!$borrado) {
        # xml de articulo no se va a cambiar, liberar mutex
        &lib_waitlock::unlock_file($LOCK, $LOCKFH);
        exit;
    }

    my ($s3_media_size, $s3_asset_size) = lib_s3::get_art_size($ts, $bucket);
    my $s3_size = $s3_media_size + $s3_asset_size;
    $artic_obj->update_s3_size($s3_size, $s3_media_size, $s3_asset_size);

    my ($disk_size, $imag_size, $asset_size, $media_size) = $artic_obj->get_disk_size();
    my $total_size = $s3_size + $disk_size;
    $artic_obj->update_art_size($total_size, $disk_size, $imag_size, $asset_size, $media_size);

    $artic_obj->_flush_xml();

    # xml de articulo ya se actualizó, se libera el mutex
    &lib_waitlock::unlock_file($LOCK, $LOCKFH);

    # actualiza datos en bd
    my ($bd, $msg) = &lib_prontus::conectar_prontus_bd();
    if (!ref($bd)) {
        return $msg;
    }
    $artic_obj->art_update_bd($bd);
}

sub tareas_salida {
    if ($LOCK ne '') {
        &lib_waitlock::unlock_file($LOCK, $LOCKFH);
    }
}

==> release.12.2.28.1.tgz: cgi-cpn/prontus_s3_erase.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# PROPOSITO .
# -----------
# Listar archivos pertenecientes a un Prontus y articulo en un almacenamiento S3
#
use strict;
use warnings;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibs = $Bin;
    unshift(@INC,$pathLibs);

    $pathLibs = "$pathLibs/mam";
    unshift(@INC, $pathLibs);
}

END {
    &tareas_salida();
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use Digest::MD5;
use File::Copy;
use HTML::Entities;
require HTTP::Headers;
use HTTP::Request;
use JSON;
use LWP::UserAgent;
use Net::Amazon::S3;
use Net::Amazon::S3::Client;
use POSIX;
use Time::Local;
use URI::Escape;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_artic;
use lib_bd;
use lib_friendly;
use lib_helper;
use lib_mam;
use lib_parser;
use lib_prontus;
use lib_s3;
use lib_tags;
use lib_tax;
use lib_urlf5;
use lib_utils;
use lib_waitlock;
##/libs##

use Data::Dumper;

our $LOCK = '';
our $LOCKFH;
our $BD;

main: {
    lib_utils::setUtf8();

    if (scalar @ARGV < 2) {
        print "Parámetros insuficientes. Modo de uso:\n";
        print "perl $0 <prontus_id> <ts_articulo>\n";
        exit;
    }

    $prontus_varglb::PRONTUS_ID = $ARGV[0];

    my $ts = '';
    if (defined($ARGV[1]) && $ARGV[1] =~ /^\d{14}$/) {
        $ts = $ARGV[1];
    } elsif ($ARGV[1]) {
        print "Parámetro [$ARGV[1]] no es válido\n";
        exit;
    }

    my $msg_load = lib_utils::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "Ha ocurrido un error: $msg_load\n";
        exit;
    }

    if (!lib_s3::check_config_s3()) {
        print STDERR "S3 no habilitado y/o configurado\n";
        exit;
    }

    my ($result, $msg_err) = lib_prontus::get_url("https://".$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'S3_ENDPOINT'}, 10);
    if ($msg_err) {
        print STDERR "Error al conectar con endpoint S3 [$msg_err]\n";
        exit;
    }

    # se asegura el xml mientras se edita y guarda
    $LOCK = "$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_LOCKS'}/$ts.mutex";
    $LOCKFH = lib_waitlock::lock_file($LOCK);

    # actualizar xml de artículo
    my $artic_obj;
    # se instancia el articulo con los campos nuevos
    unless($artic_obj = Artic->new(
                'prontus_id'         => $prontus_varglb::PRONTUS_ID,
                'public_server_name' => $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'PUBLIC_SERVER_NAME'},
                'cpan_server_name'   => $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'CPAN_SERVER_NAME'},
                'document_root'      => $prontus_varglb::DIR_SERVER,
                'ts'                 => $ts,
                'no_check_dirs'      => 1)) {
        print STDERR "[Error] inicializando objeto articulo: $Artic::ERR\n";
        exit;
    };

    $artic_obj->{xml_data} = glib_fildir_03::read_file($artic_obj->{fullpath_xml});

    my $fechac = substr($ts, 0, 8);
    # buscamos campos en articulo para borrar archivos que ya no pertenecen al artículo
    my %campos_xml = %{lib_artic::carga_art_xml($artic_obj->{fullpath_xml})};

    my $dst_base = substr($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'}, 1);
    my $dst_base_mm    = "$dst_base$prontus_varglb::DIR_EXMEDIA/$fechac$prontus_varglb::DIR_MMEDIA/";
    my $dst_base_docs  = "$dst_base$prontus_varglb::DIR_ASOCFILE/$fechac/$ts/";

    my %asocfiles;
    my @multimedia;
    foreach my $nom (keys %campos_xml) {
        if ($nom =~ /^multimedia_\w+$/) {
            push(@multimedia, $nom);
        }
        elsif ($nom =~ /^asocfile_\w+$/) {
            $asocfiles{"$dst_base_docs$campos_xml{$nom}"} = 1;
        }
    }

    lib_s3::connect_s3();
    my $bucket = lib_s3::connect_bucket();

    my $borrado = 0;
    my @s3_files = lib_s3::list_files_pattern($bucket, $dst_base_mm);
    foreach my $remote (@s3_files) {
        next if ($remote->key !~ /$ts/);
        my $found = 0;
        foreach my $marca (@multimedia) {
            if ($remote->key =~ /$marca$ts/) {
                $found = 1;
                last;
            }
        }
        if (!$found) {
            lib_s3::delete_file_key($bucket, $remote->key);
            $borrado = 1;
        }
    }

    @s3_files = lib_s3::list_files_pattern($bucket, $dst_base_docs);
    foreach my $remote (@s3_files) {
        if (!defined($asocfiles{$remote->key})) {
            lib_s3::delete_file_key($bucket, $remote->key);
            $borrado = 1;
        }
    }

    # no se borro nada del s3, no hay que actualizar el tamaño del artículo
    if (!$borrado) {
        # xml de articulo no se va a cambiar, liberar mutex
        lib_waitlock::unlock_file($LOCK, $LOCKFH);
        exit;
    }

    my ($s3_media_size, $s3_asset_size) = lib_s3::get_art_size($ts, $bucket);
    my $s3_size = $s3_media_size + $s3_asset_size;
    $artic_obj->update_s3_size($s3_size, $s3_media_size, $s3_asset_size);

    my ($disk_size, $imag_size, $asset_size, $media_size) = $artic_obj->get_disk_size();
    my $total_size = $s3_size + $disk_size;
    $artic_obj->update_art_size($total_size, $disk_size, $imag_size, $asset_size, $media_size);

    $artic_obj->_flush_xml();

    # xml de articulo ya se actualizó, se libera el mutex
    lib_waitlock::unlock_file($LOCK, $LOCKFH);

    # actualiza datos en bd
    my ($bd, $msg) = lib_bd::conectar_prontus_bd();
    if (!ref($bd)) {
        return $msg;
    }
    $artic_obj->art_update_bd($bd);
}

sub tareas_salida {
    if ($LOCK ne '') {
        lib_waitlock::unlock_file($LOCK, $LOCKFH);
    }
}
